/*
 * win/dpPort.h --
 *
 *	This file is included by all of the DP C files.  It contains
 *	information that are specific for the MS Windows environment,
 *	such as header files and a few other things.
 *
 * Copyright (c) 1995-1996 The Regents of Cornell University.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef _DPWINPORT
#define _DPWINPORT

#include <stdlib.h>
#include <string.h>
#include <errno.h>

/*
 * VC++ has an alternate entry point called DllMain, so we need to rename
 * our entry point.
 */

#   if defined(_MSC_VER)
#	define EXPORT(a,b) __declspec(dllexport) a b
#	define DllEntryPoint DllMain
#   else
#	if defined(__BORLANDC__)
#	    define EXPORT(a,b) a _export b
#	else
#	    define EXPORT(a,b) a b
#	endif
#   endif

#ifndef _WINSOCKAPI_
#    include <winsock.h>
#endif

#define NONBLOCKING(flags)	(flags & O_NONBLOCK)
#define DP_INVALID_SOCKET	INVALID_SOCKET
#define DP_SOCKET		TCL_WIN_SOCKET
#define SERIAL_HANDLE		TCL_WIN_FILE
#define DP_SOCKET_ERROR		SOCKET_ERROR
#define DP_INADDR_NONE		INADDR_NONE
#define ASYNC_CONNECT_ERROR	EWOULDBLOCK

/*
 * The following are abstract types for socket handles and IP addresses
 */
typedef SOCKET		DpSocket;
typedef struct sockaddr		DpSocketAddress;
typedef struct sockaddr_in	DpSocketAddressIP;
typedef HANDLE			SerialHandle;

/*
 * The following structure is initialized by WSAStartup in DppInit().
 * It contains general information about the winsock library and
 * underlying network.  It contains the following elements:
 *
 *  WORD             wVersion		The version number that we're using
 *					(two bytes)
 *  WORD             wHighVersion	The highest version # supported by dll
 *  char             szDescription[]	A description of the Windows Sockets
 *					implementation, including vendor
 *					identification. Can contain
 *					any characters.
 *  char             szSystemStatus[]	Relevant status or configuration
 *					information.
 *  unsigned short   iMaxSockets	The maximum number of sockets
 *					which a single process can potentially
 *					open.
 *  unsigned short   iMaxUdpDg		The size in bytes of the largest UDP
 *					datagram that can be sent or received
 *					by a Windows Sockets application.
 *					If the implementation imposes no
 *					limit, iMaxUdpDg is zero.
 *  char FAR *       lpVendorInfo	A pointer to a vendor-specific data
 *					structure. See Programming with
 *					Sockets in the Win32 SDK documentation.
 */
WSADATA dpStartUpInfo; 

#define DP_INADDR_ANY		1

/*
 * Serial Port stuff
 */

/*
 * Type of parity - these constants may also be
 * defined in winbase.h so if they are already defined
 * we don't bother....
 */

#if !defined(PARITY_NONE)
#  define PARITY_NONE		0
#  define PARITY_ODD		1
#  define PARITY_EVEN		2
#endif

#endif /* _DPWINPORT */
